# eric7.Utilities.MouseUtilities

Module implementing utility functions related to Mouse stuff.

### Global Attributes

__button2String
__modifier2String
__modifierOrder

### Classes

None

### Functions

MouseButtonModifier2String | Function to convert a modifier and mouse button combination to a displayable string.

## MouseButtonModifier2String

MouseButtonModifier2String(modifiers, button)

Function to convert a modifier and mouse button combination to a displayable string.

modifiers (Qt.KeyboardModifiers)
  keyboard modifiers of the handler
button (Qt.MouseButton)
  mouse button of the handler

Return:
  display string of the modifier and mouse button combination

Return Type:
  str

Up